import type { Pipeline, PipelinePolicy } from "@azure/core-rest-pipeline";
export declare const disableKeepAlivePolicyName = "DisableKeepAlivePolicy";
export declare function createDisableKeepAlivePolicy(): PipelinePolicy;
/**
 * @internal
 */
export declare function pipelineContainsDisableKeepAlivePolicy(pipeline: Pipeline): boolean;
//# sourceMappingURL=disableKeepAlivePolicy.d.ts.map